LiquidGlassLayer class
Represents a layer of multiple LiquidGlass shapes that have shared LiquidGlassSettings and will be rendered together.
Impeller Required: Liquid glass rendering requires Impeller to be enabled. On non-Impeller devices (Skia), the effect automatically falls back to fake glass rendering using standard backdrop filters.
Performance: Impeller-based liquid glass provides better visual quality AND better performance than fake glass, because it uses custom shaders that run entirely on the GPU.
If you create a LiquidGlassLayer with one or more LiquidGlass widgets, the liquid glass effect will be rendered where this layer is.
Make sure not to stack any other widgets between the LiquidGlassLayer and the LiquidGlass widgets, otherwise the liquid glass effect will be behind them.
Example
Widget build(BuildContext context) {
return LiquidGlassLayer(
child: Column(
children: [
LiquidGlass(
shape: LiquidRoundedSuperellipse(
borderRadius: 10,
),
child: const SizedBox.square(
dimension: 100,
),
),
const SizedBox(height: 16),
LiquidGlass(
shape: const LiquidOval(),
child: const SizedBox.square(
dimension: 100,
),
),
],
),
);
}
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LiquidGlassLayer
Constructors
- LiquidGlassLayer({required Widget child, LiquidGlassSettings settings = const LiquidGlassSettings(), bool useBackdropGroup = false, Key? key})
-
Creates a new LiquidGlassLayer with the given
childandsettings.const
Properties
- child → Widget
-
The subtree in which you should include at least one LiquidGlass widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → LiquidGlassSettings
-
The settings for the liquid glass effect for all shapes in this layer.
final
- useBackdropGroup → bool
-
Whether to look up the tree for a BackdropGroup to use for this layer's
blur.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LiquidGlassLayer> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited